@@ -205,3 +205,7 @@ func (s *store) AddVulnerabilityMetadata(metadata ...v1.VulnerabilityMetadata) e
 	}
 	return nil
 }
+
+func (s *store) Close() {
+	s.db.Exec("VACUUM;")
+}
