@@ -18,3 +18,16 @@ type Cvss struct {
 	ImpactScore         float64 // Representation of the effects of an exploited vulnerability relative to compromise in confidentiality, integrity, and availability
 	Vector              string  // A textual representation of the metric values used to determine the score
 }
+
+type VulnerabilityMetadataStore interface {
+	VulnerabilityMetadataStoreReader
+	VulnerabilityMetadataStoreWriter
+}
+
+type VulnerabilityMetadataStoreReader interface {
+	GetVulnerabilityMetadata(id, recordSource string) (*VulnerabilityMetadata, error)
+}
+
+type VulnerabilityMetadataStoreWriter interface {
+	AddVulnerabilityMetadata(metadata ...VulnerabilityMetadata) error
+}
