@@ -204,3 +204,7 @@ func (s *store) AddVulnerabilityMetadata(metadata ...v2.VulnerabilityMetadata) e
 	}
 	return nil
 }
+
+func (s *store) Close() {
+	s.db.Exec("VACUUM;")
+}
