@@ -1,5 +1,7 @@
 package v3
 
+type SerializedVulnerabilityMetadata = interface{}
+
 type VulnerabilityMetadataStore interface {
 	VulnerabilityMetadataStoreReader
 	VulnerabilityMetadataStoreWriter
@@ -7,6 +9,7 @@ type VulnerabilityMetadataStore interface {
 
 type VulnerabilityMetadataStoreReader interface {
 	GetVulnerabilityMetadata(id, namespace string) (*VulnerabilityMetadata, error)
+	GetAllVulnerabilityMetadata() (*[]VulnerabilityMetadata, error)
 }
 
 type VulnerabilityMetadataStoreWriter interface {
