@@ -1,19 +1,15 @@
 package apk
 
 import (
-	"errors"
 	"fmt"
-	"strings"
 
 	"github.com/anchore/grype/grype/distro"
 	"github.com/anchore/grype/grype/match"
-	"github.com/anchore/grype/grype/matcher/common"
 	"github.com/anchore/grype/grype/pkg"
+	"github.com/anchore/grype/grype/search"
 	"github.com/anchore/grype/grype/version"
 	"github.com/anchore/grype/grype/vulnerability"
 	syftPkg "github.com/anchore/syft/syft/pkg"
-	"github.com/jinzhu/copier"
-	"github.com/scylladb/go-set/strset"
 )
 
 type Matcher struct {
@@ -49,7 +45,7 @@ func (m *Matcher) Match(store vulnerability.Provider, d *distro.Distro, p pkg.Pa
 
 func (m *Matcher) cpeMatchesWithoutSecDBFixes(store vulnerability.Provider, d *distro.Distro, p pkg.Package) ([]match.Match, error) {
 	// find CPE-indexed vulnerability matches specific to the given package name and version
-	cpeMatches, err := common.FindMatchesByPackageCPE(store, p, m.Type())
+	cpeMatches, err := search.ByPackageCPE(store, p, m.Type())
 	if err != nil {
 		return nil, err
 	}
@@ -139,7 +135,7 @@ func vulnerabilitiesByID(vulns []vulnerability.Vulnerability) map[string][]vulne
 
 func (m *Matcher) findApkPackage(store vulnerability.Provider, d *distro.Distro, p pkg.Package) ([]match.Match, error) {
 	// find Alpine SecDB matches for the given package name and version
-	secDBMatches, err := common.FindMatchesByPackageDistro(store, d, p, m.Type())
+	secDBMatches, err := search.ByPackageDistro(store, d, p, m.Type())
 	if err != nil {
 		return nil, err
 	}
@@ -161,67 +157,19 @@ func (m *Matcher) findApkPackage(store vulnerability.Provider, d *distro.Distro,
 }
 
 func (m *Matcher) matchBySourceIndirection(store vulnerability.Provider, d *distro.Distro, p pkg.Package) ([]match.Match, error) {
-	// build indirect package for matching against source package
-	indirectPackage, err := buildIndirectPackage(p)
-	if err != nil {
-		// If the err is that there no indirect package return empty slice
-		if errors.Is(err, errNoIndirectPackage) {
-			return nil, nil
-		}
-		return nil, fmt.Errorf("failed to build an indirect package for: %s", p.Name)
-	}
+	var matches []match.Match
 
-	matches, err := m.findApkPackage(store, d, indirectPackage)
-	if err != nil {
-		return nil, fmt.Errorf("failed to find vulnerabilities by apk source indirection: %w", err)
+	for _, indirectPackage := range pkg.UpstreamPackages(p) {
+		indirectMatches, err := m.findApkPackage(store, d, indirectPackage)
+		if err != nil {
+			return nil, fmt.Errorf("failed to find vulnerabilities for apk upstream source package: %w", err)
+		}
+		matches = append(matches, indirectMatches...)
 	}
 
 	// we want to make certain that we are tracking the match based on the package from the SBOM (not the indirect package)
 	// however, we also want to keep the indirect package around for future reference
-	for idx := range matches {
-		matches[idx].Package = p
-
-		if matches[idx].Type == match.ExactDirectMatch {
-			matches[idx].Type = match.ExactIndirectMatch
-		}
-	}
+	match.ConvertToIndirectMatches(matches, p)
 
 	return matches, nil
 }
-
-// Custom error for when indirect package is not present or is identical to package
-var errNoIndirectPackage = errors.New("source package is either identical to pkg or not present")
-
-func buildIndirectPackage(p pkg.Package) (pkg.Package, error) {
-	metadata, ok := p.Metadata.(pkg.ApkMetadata)
-	// ignore packages without source indirection hints or where source name is identical to package name
-	if !ok || metadata.OriginPackage == "" || metadata.OriginPackage == p.Name {
-		return pkg.Package{}, errNoIndirectPackage
-	}
-
-	var indirectPackage pkg.Package
-	err := copier.Copy(&indirectPackage, p)
-	if err != nil {
-		return pkg.Package{}, fmt.Errorf("failed to copy package: %w", err)
-	}
-
-	// use the source package name
-	indirectPackage.Name = metadata.OriginPackage
-
-	// For each cpe, replace pkg name with origin and add to set
-	cpeStrings := strset.New()
-	for _, cpe := range indirectPackage.CPEs {
-		updatedCPEString := strings.ReplaceAll(cpe.BindToFmtString(), p.Name, indirectPackage.Name)
-		cpeStrings.Add(updatedCPEString)
-	}
-
-	// With each entry in set, convert string to CPE and update indirectPackage CPEs
-	var updatedCPEs []syftPkg.CPE
-	for _, cpeString := range cpeStrings.List() {
-		updatedCPE, _ := syftPkg.NewCPE(cpeString)
-		updatedCPEs = append(updatedCPEs, updatedCPE)
-	}
-	indirectPackage.CPEs = updatedCPEs
-
-	return indirectPackage, nil
-}
