@@ -16,6 +16,10 @@ func TestParseFormat(t *testing.T) {
 			input:  "dpkg",
 			format: DebFormat,
 		},
+		{
+			input:  "gem",
+			format: GemFormat,
+		},
 		{
 			input:  "deb",
 			format: DebFormat,
@@ -52,7 +56,7 @@ func TestFormatFromPkgType(t *testing.T) {
 		},
 		{
 			pkgType: pkg.GemPkg,
-			format:  SemanticFormat,
+			format:  GemFormat,
 		},
 	}
 
