@@ -600,10 +600,11 @@ func TestMatchByImage(t *testing.T) {
 
 			vp, err := db.NewVulnerabilityProvider(theStore)
 			require.NoError(t, err)
+			mp := db.NewVulnerabilityMetadataProvider(theStore)
 			ep := db.NewMatchExclusionProvider(theStore)
 			str := store.Store{
 				Provider:          vp,
-				MetadataProvider:  nil,
+				MetadataProvider:  mp,
 				ExclusionProvider: ep,
 			}
 
