@@ -4,6 +4,8 @@ import (
 	"context"
 	"fmt"
 	"io"
+	"sort"
+	"strings"
 	"sync"
 	"time"
 
@@ -15,6 +17,8 @@ import (
 	"github.com/wagoodman/jotframe/pkg/frame"
 
 	grypeEventParsers "github.com/anchore/grype/grype/event/parsers"
+	"github.com/anchore/grype/grype/matcher"
+	"github.com/anchore/grype/grype/vulnerability"
 	"github.com/anchore/grype/internal/ui/components"
 	syftUI "github.com/anchore/syft/ui"
 )
@@ -24,8 +28,10 @@ const statusSet = components.SpinnerDotSet // SpinnerCircleOutlineSet
 const completedStatus = "✔"                // "●"
 const tileFormat = color.Bold
 
-var auxInfoFormat = color.HEX("#777777")
-var statusTitleTemplate = fmt.Sprintf(" %%s %%-%ds ", syftUI.StatusTitleColumn)
+var (
+	auxInfoFormat       = color.HEX("#777777")
+	statusTitleTemplate = fmt.Sprintf(" %%s %%-%ds ", syftUI.StatusTitleColumn)
+)
 
 func startProcess() (format.Simple, *components.Spinner) {
 	width, _ := frame.GetTerminalSize()
@@ -92,48 +98,116 @@ func (r *Handler) UpdateVulnerabilityDatabaseHandler(ctx context.Context, fr *fr
 	return err
 }
 
-//nolint:dupl
+func scanningAndSummaryLines(fr *frame.Frame) (scanningLine, summaryLine, fixedLine *frame.Line, err error) {
+	scanningLine, err = fr.Append()
+	if err != nil {
+		return nil, nil, nil, err
+	}
+
+	summaryLine, err = fr.Append()
+	if err != nil {
+		return nil, nil, nil, err
+	}
+
+	fixedLine, err = fr.Append()
+	if err != nil {
+		return nil, nil, nil, err
+	}
+	return scanningLine, summaryLine, fixedLine, nil
+}
+
+func assembleProgressMonitors(m *matcher.Monitor) []progress.Monitorable {
+	ret := []progress.Monitorable{
+		m.PackagesProcessed,
+		m.VulnerabilitiesDiscovered,
+	}
+
+	allSeverities := append([]vulnerability.Severity{vulnerability.UnknownSeverity}, vulnerability.AllSeverities()...)
+	for _, sev := range allSeverities {
+		ret = append(ret, m.BySeverity[sev])
+	}
+
+	ret = append(ret, m.Fixed)
+
+	return ret
+}
+
+//nolint:funlen
 func (r *Handler) VulnerabilityScanningStartedHandler(ctx context.Context, fr *frame.Frame, event partybus.Event, wg *sync.WaitGroup) error {
 	monitor, err := grypeEventParsers.ParseVulnerabilityScanningStarted(event)
 	if err != nil {
 		return fmt.Errorf("bad %s event: %w", event.Type, err)
 	}
 
-	line, err := fr.Append()
+	scanningLine, summaryLine, fixLine, err := scanningAndSummaryLines(fr)
 	if err != nil {
 		return err
 	}
 
 	wg.Add(1)
 
-	_, spinner := startProcess()
-	stream := progress.StreamMonitors(ctx, []progress.Monitorable{monitor.PackagesProcessed, monitor.VulnerabilitiesDiscovered}, 50*time.Millisecond)
-	title := tileFormat.Sprint("Scanning image...")
+	monitors := assembleProgressMonitors(monitor)
 
-	formatFn := func(val int64) {
-		spin := color.Magenta.Sprint(spinner.Next())
-		auxInfo := auxInfoFormat.Sprintf("[vulnerabilities %d]", val)
-		_, _ = io.WriteString(line, fmt.Sprintf(statusTitleTemplate+"%s", spin, title, auxInfo))
+	_, spinner := startProcess()
+	stream := progress.StreamMonitors(ctx, monitors, 50*time.Millisecond)
+
+	title := tileFormat.Sprint("Scanning image...")
+	branch := "├──"
+	end := "└──"
+
+	fixTempl := "%d fixed"
+
+	formatFn := func(m *matcher.Monitor, complete bool) {
+		var spin string
+		if complete {
+			spin = color.Green.Sprint(completedStatus)
+		} else {
+			spin = color.Magenta.Sprint(spinner.Next())
+		}
+
+		auxInfo := auxInfoFormat.Sprintf("[%d vulnerabilities]", m.VulnerabilitiesDiscovered.Current())
+		_, _ = io.WriteString(scanningLine, fmt.Sprintf(statusTitleTemplate+"%s", spin, title, auxInfo))
+
+		var unknownStr string
+		unknown := m.BySeverity[vulnerability.UnknownSeverity].Current()
+		if unknown > 0 {
+			unknownStr = fmt.Sprintf(" (%d unknown)", unknown)
+		}
+
+		allSeverities := vulnerability.AllSeverities()
+		sort.Sort(sort.Reverse(vulnerability.Severities(allSeverities)))
+
+		var builder strings.Builder
+		for idx, sev := range allSeverities {
+			count := m.BySeverity[sev].Current()
+			builder.WriteString(fmt.Sprintf("%d %s", count, sev))
+			if idx < len(allSeverities)-1 {
+				builder.WriteString(", ")
+			}
+		}
+		builder.WriteString(unknownStr)
+
+		status := builder.String()
+		auxInfo2 := auxInfoFormat.Sprintf("   %s %s", branch, status)
+		_, _ = io.WriteString(summaryLine, auxInfo2)
+
+		fixStatus := fmt.Sprintf(fixTempl, m.Fixed.Current())
+		_, _ = io.WriteString(fixLine, auxInfoFormat.Sprintf("   %s %s", end, fixStatus))
 	}
 
 	go func() {
 		defer wg.Done()
 
-		formatFn(0)
-		for p := range stream {
-			formatFn(p[1])
+		formatFn(monitor, false)
+		for range stream {
+			formatFn(monitor, false)
 		}
-
-		spin := color.Green.Sprint(completedStatus)
-		title = tileFormat.Sprint("Scanned image")
-		auxInfo := auxInfoFormat.Sprintf("[%d vulnerabilities]", monitor.VulnerabilitiesDiscovered.Current())
-		_, _ = io.WriteString(line, fmt.Sprintf(statusTitleTemplate+"%s", spin, title, auxInfo))
+		formatFn(monitor, true)
 	}()
 
 	return nil
 }
 
-//nolint:dupl
 func (r *Handler) DatabaseDiffingStartedHandler(ctx context.Context, fr *frame.Frame, event partybus.Event, wg *sync.WaitGroup) error {
 	monitor, err := grypeEventParsers.ParseDatabaseDiffingStarted(event)
 	if err != nil {
